/* *********************************************************************** */
/*                                                                         */
/* Library : Matlab Command (matlabcom)                                    */
/* File    : mat_elem_base.C : gives a mat elem types.                     */
/*     									   */
/*                                                                         */
/* Date : Octobre 11, 2001.                                                */
/* Author : Yves Renard, Yves.Renard@gmm.insa-tlse.fr                      */
/*                                                                         */
/* *********************************************************************** */
/*                                                                         */
/* Copyright (C) 2001  Yves Renard.                                        */
/*                                                                         */
/* This file is a part of GETFEM++                                         */
/*                                                                         */
/* This program is free software; you can redistribute it and/or modify    */
/* it under the terms of the GNU General Public License as published by    */
/* the Free Software Foundation; version 2 of the License.                 */
/*                                                                         */
/* This program is distributed in the hope that it will be useful,         */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of          */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           */
/* GNU General Public License for more details.                            */
/*                                                                         */
/* You should have received a copy of the GNU General Public License       */
/* along with this program; if not, write to the Free Software Foundation, */
/* Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.         */
/*                                                                         */
/* *********************************************************************** */

#include "mex.h"
#include <matlabint_matelemtype.h>
#include <matlabint_pfem.h>

#define id_type matlabint::id_type

/**@name k = mat_elem_base(pfi)
 * return an identifier on the type of elementary matrices which represents
 * integration of shape functions of fem interpolation pfi on elements.
 */
//@{
//@}

void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
  if (nrhs != 1)
    mexErrMsgTxt("Wrong number of input arguments.");
  else if (nlhs != 1)
    mexErrMsgTxt("Wrong number of output argument.");
  id_type *p1 = (id_type *)(mxGetData(prhs[0]));
  if (mxGetClassID(prhs[0]) != mxUINT32_CLASS 
      || (*p1 & 0xFF000000) != MATLABINT_PFEM_MASK)
    mexErrMsgTxt("First input argument should be a fem interpolation descriptor");

  id_type a = *p1 - MATLABINT_PFEM_MASK;
  if (!matlabint::exists_pfem(a))
    mexErrMsgTxt("Fem corresponding to first argument does not exist.");
  
  int j = 1;
  plhs[0] = mxCreateNumericArray(1, &j, mxUINT32_CLASS, mxREAL);
  *((id_type *)(mxGetData(plhs[0]))) = matlabint::ind_matelemtype(getfem::mat_elem_base(matlabint::addr_pfem(a))) + MATLABINT_MATELEMTYPE_MASK;
 
}
